Package: gpbStat
Type: Package
Title: Comprehensive Statistical Analysis of Plant Breeding Experiments
Version: 0.4.4
Authors@R: 
    c(person(given = "Nandan",
           family = "Patil",
           role = c("aut", "cre"),
           email = "tryanother609@gmail.com",
           comment = c(ORCID = "0000-0003-0100-9931"))
     , person(given = "Lakshmi",
           family = "Gangavati",
           role = c("aut", "ctb"),
           email = "lakshmirg8@gmail.com")
         )
Maintainer: Nandan Patil <tryanother609@gmail.com>
Note: Department of Genetics and Plant Breeding, University of
        Agricultural Sciecnes, Dharwad.
Description: Performs statistical data analysis of various Plant Breeding experiments. Contains functions for Line by Tester analysis as per Arunachalam, V.(1974) <http://repository.ias.ac.in/89299/> and Diallel analysis as per Griffing, B. (1956) <https://www.publish.csiro.au/bi/pdf/BI9560463>.  
License: GPL-2
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0)
Date: 2024-10-12
URL: https://github.com/nandp1/gpbStat/
BugReports: https://github.com/nandp1/gpbStat/issues
RoxygenNote: 7.3.2
Imports: tidyr, purrr, tibble, magrittr, dplyr
Suggests: testthat, knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-10-12 07:21:50 UTC; PATIL
Author: Nandan Patil [aut, cre] (<https://orcid.org/0000-0003-0100-9931>),
  Lakshmi Gangavati [aut, ctb]
Repository: CRAN
Date/Publication: 2024-10-12 07:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:47:34 UTC; unix
