# Generated by roxygen2: do not edit by hand

export("%>%")
export(dm2)
export(dti)
export(ltc)
export(ltcchk)
export(ltcmt)
export(ltcs)
import(graphics)
import(magrittr)
import(stats)
importFrom(dplyr,bind_cols)
importFrom(dplyr,select)
importFrom(magrittr,"%>%")
importFrom(purrr,map)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,pivot_longer)
