---
title: "dti: Estimation of Drought Tolerance Indices"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{dti}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

Estimation of indices which represent the drought tolerance capacity of genotypes. 

The function can handle both replicated and non-replicated data refer the examples.

## Example: Estimating drought tolerance indices

```{r setup}
library(gpbStat)
data(datdti)
result1 =  dti(datdti, environment = ENV, genotype = GEN, datdti[,3:8],
               ns = 'NS-DWR', st = 'ST-DWR')
result1

data(datrdti)
result2 = dti(datrdti, environment = ENV, genotype = GEN, datrdti[,4:9],
             ns = 'NS-DWR', st = 'ST-DWR')
result2
```
